# Objection.py

A modular library for programmatically creating [objection.lol](https://objection.lol/maker) projects

### TODO

- Complete: galleryAssign option for custom characters
- Complete: improve tests for scene features and for objection JSON loading
